@@ -3,9 +3,9 @@
 import glog
 import networkx as nx
 from typing import List, Dict
+import uuid
 
 import ascend.protos.api.api_pb2 as api_pb2
-import ascend.protos.io.io_pb2 as io_pb2
 from ascend.sdk.client import Client
 from ascend.sdk.definitions import (Component, Connection, Credential, Dataflow, ReadConnector, Transform, WriteConnector, ComponentGroup, ComponentIdToUuidMap,
                                     ComponentUuidType, DataFeed, DataFeedConnector, DataService)
@@ -101,9 +101,8 @@ class DataServiceApplier:
       for credential in self.client.list_data_service_credentials(data_service.id).data:
         if credential.name not in expected:
           if len(credential.owner_orgs) != 1:
-            glog.info(
-                f"Skip Delete for Credential shared with multiple data services: (ds={data_service.id} credential_id={credential.credential_id} {credential.name}"
-            )
+            glog.info("Skip Delete for Credential shared with multiple data services:"
+                      f" (ds={data_service.id} credential_id={credential.credential_id} {credential.name}")
             continue
           glog.info(f"Delete Credential: (ds={data_service.id} credential_id={credential.credential_id} {credential.name})")
           if not dry_run:
@@ -131,7 +130,6 @@ class CredentialApplier:
       if not dry_run:
         existing = self.client.update_data_service_credentials(data_service_id, credential.id, credential_p).data
     else:
-      credential.id = credential.credential.id.value = ""
       glog.info(f"Create Credential: (ds={data_service_id} credential_id={credential.id} name={credential.name})")
       if not dry_run:
         existing = self.client.create_data_service_credentials(data_service_id, credential_p).data
@@ -167,7 +165,12 @@ class ConnectionApplier:
         # short term hack as we aren't getting full results from the API on creation (See FP2021-49)
         existing = self.client.get_connection(data_service_id, res.data.id.value).data
     else:
-      connection.id = ""
+      try:
+        # backward compatible check, if it is uuid, set to empty string so existing env without friendly id code still works
+        uuid.UUID(connection.id)
+        connection.id = ""
+      except Exception as e:
+        glog.debug(f"non uuid string, treat it as friendly id {connection.id}")
       glog.info(f"Create Connection: (ds={data_service_id} id={connection.id} name={connection.name})")
       if not dry_run:
         existing = self.client.create_connection(data_service_id, connection.to_proto()).data
@@ -530,7 +533,7 @@ def _component_id_map_from_list(components: List[Component]) -> Dict[str, Compon
   id_to_component: Dict[str, Component] = {}
   for component in components:
     if not component.id:
-      raise ValueError(f"empty component id")
+      raise ValueError("empty component id")
     elif component.id in id_to_component:
       raise ValueError(f"duplicate component id {component.id} in component list")
     else:
