@@ -495,7 +495,13 @@ class Credential(Definition):
 
 class Connection(Definition):
   """A connection"""
-  def __init__(self, id: str, name: str, type_id: str, credential_id: str, details: Dict[str, ascend_pb2.Value]):
+  def __init__(self,
+               id: str,
+               name: str,
+               type_id: str,
+               credential_id: str,
+               details: Dict[str, ascend_pb2.Value],
+               access_mode: Optional[connection_pb2.AccessMode] = None):
     """
     Create a Connection definition.
 
@@ -505,6 +511,7 @@ class Connection(Definition):
     - type_id: the type of connection
     - credential_id: the id of the credential to use
     - details: a dictionary of the connection details
+    - access_mode: read-only (default), write-only, or read-write access mode of the connection
     Returns: a new Connection instance.
     """
     self.id = id
@@ -512,6 +519,7 @@ class Connection(Definition):
     self.type_id = type_id
     self.credential_id = credential_id
     self.details = details
+    self.access_mode = access_mode
 
   def to_proto(self):
     try:
@@ -519,7 +527,8 @@ class Connection(Definition):
                                name=self.name,
                                type_id=connection_pb2.Type.Id(value=self.type_id),
                                credential_id=io_pb2.Credentials.Id(value=self.credential_id) if self.credential_id else None,
-                               details=self.details)
+                               details=self.details,
+                               access_mode=self.access_mode)
     except KeyError as e:
       raise KeyError(f"unresolved id for connection {e}")
 
@@ -527,7 +536,13 @@ class Connection(Definition):
   def from_proto(proto: io_pb2.Connection) -> 'Connection':
     try:
       details = {k: proto.details[k] for k in proto.details.keys()} if hasattr(proto, "details") else None
-      return Connection(id=proto.id.value, name=proto.name, type_id=proto.type_id.value, credential_id=proto.credential_id.value, details=details)
+      access_mode = proto.access_mode if proto.HasField("access_mode") else None
+      return Connection(id=proto.id.value,
+                        name=proto.name,
+                        type_id=proto.type_id.value,
+                        credential_id=proto.credential_id.value,
+                        details=details,
+                        access_mode=access_mode)
     except KeyError as e:
       raise KeyError(f"unresolved id for component {e}")
 
