@@ -101,8 +101,18 @@ def download_dataflow(client: Client, data_service_id: str, dataflow_id: str, re
     raise ValueError(f"Specified resource path ({resource_base_path}) must be a directory")
 
   df_proto = client.get_dataflow(data_service_id=data_service_id, dataflow_id=dataflow_id).data
+
   dataflow = dataflow_from_proto(client, data_service_id, df_proto)
 
+  # translate connection id to friendly id
+  connections = client.list_connections(data_service_id)
+  cids_map = {x.id.value: x.entity_metadata.id for x in connections.data}
+  for c in dataflow.components:
+    cid = c.container.record_connection.connection_id.value if hasattr(c, 'container') else None
+    friendly_id = cids_map.get(cid) if cid else None
+    if friendly_id:
+      c.container.record_connection.connection_id.value = friendly_id
+
   dataflow_resource_path = os.path.join(resource_base_path, f"{dataflow.id}")
   dataflow_path = os.path.join(resource_base_path, f"{dataflow.id}.py")
   glog.info(f"Writing dataflow definition to ({dataflow_path})" f" and dataflow resource files to ({dataflow_resource_path})")
@@ -395,12 +405,13 @@ def _render_array(arr, attribute_path: Tuple[str, ...], indent=0, classname_map:
 
 def _render_map(mp, attribute_path: Tuple[str, ...], indent=0, classname_map: dict = {}, attribute_overrides: dict = {}):
   tmpl = jinja2.Template('''{
-{% for k, v in mp.items() %}\
+{% for k in sorted(mp.keys()) %}\
 {{_spaces_for(indent+2)}}{{_render_value(k, attribute_path, indent+2, classname_map, attribute_overrides)}}: \
-{{ _render_value(v, attribute_path, indent+2, classname_map, attribute_overrides) }},\n\
+{{ _render_value(mp[k], attribute_path, indent+2, classname_map, attribute_overrides) }},\n\
 {% endfor %}\
 {{_spaces_for(indent)}}}''')
   return tmpl.render(mp=mp,
+                     sorted=sorted,
                      _render_value=_render_value,
                      _spaces_for=_spaces_for,
                      indent=indent,
